Learn R Programming

PIGShift (version 1.0.1)

dmvnorminvgamma: Compute the pdf for multi-variate normal-inverse-gamma random variates

Description

This function returns the multi-variate normal-inverse-gamma density evaluated at specific points

Usage

dmvnorminvgamma(x, mu, alpha, beta, T, log = FALSE)

Arguments

x
a matrix where each row is a sample and each column is a dimension.
mu
a vector indicating the mean in each dimension
alpha
shape parameter of the inverse gamma distribution
beta
scale parameter of the inverse gamma distribution
T
the variance-covariance matrix
log
a logical indicated whether to return the log of the pdf

Value

A vector densities corresponding to the rows of x