yeast.homozygote: Yeast homozygote transcription profiles
Description
This dataset has normalized log-fold-change in RNA levels between 3 yeast species and S. cerevisiae. Generated by performing RNAseq on homozygotes of each species to quantify expression.
Format
A matrix with 4 rows and 4835 columns. Each row is a species and each column is a gene.Source
Schraiber, et al (2013). Inferring evolutionary histories of pathway regulation from transcriptional profiling data. PLoS Computational Biology 9:e10003255.