OU.invgamma.like.norm: Calculate the likelihood of normalized comparative data as OUs with inverse gamma distributed rates
Description
This function calculates the likelihood of the observed
trait data assuming that each trait evolves according to an
independent Ornstein Ulenbeck processes with inverse gamma
distributed rates. The data are normalized relative to the
trait values in a specified species.