norminvgamma.shift.like.norm: Calculate the likelihood of normalized comparative data as Brownian motions with inverse gamma distributed rates
Description
This function calculates the likelihood of the observed
trait data assuming that each trait evolves according to an
independent Brownian motion with inverse gamma distributed
rates. The data are normalized relative to the trait values
in a specified species.